// Copyright (c) 1981-86 Robert A. Koeneke
// Copyright (c) 1987-94 James E. Wilson
//
// This work is free software released under the GNU General Public License
// version 2.0, and comes with ABSOLUTELY NO WARRANTY.
//
// See LICENSE and AUTHORS for more information.

#pragma once

bool enterWizardMode();
void wizardCureAll();
void wizardDropRandomItems();
void wizardJumpLevel();
void wizardGainExperience();
void wizardSummonMonster();
void wizardLightUpDungeon();
void wizardCharacterAdjustment();
void wizardGenerateObject();
void wizardCreateObjects();
